@@ -22,11 +22,11 @@ class AdminArea(Feature):
             url(self.prefix, include(admin.site.urls)),
         )
 
-
 class AdminThemeSuit(Feature):
 
-    def __init__(self, title='My site'):
+    def __init__(self, title='My site', menu=None):
         self.title = title
+        self.menu = menu
 
     def get_required_packages(self, cls):
         return 'django-suit',
@@ -43,4 +43,8 @@ class AdminThemeSuit(Feature):
             'ADMIN_NAME': self.title
         }
 
+        if self.menu:
+            cls.SUIT_CONFIG['MENU'] = self.menu
+
+
         cls.TEMPLATE_DIRS += (os.path.dirname(os.path.dirname(__file__)) + '/templates/suit-feature',)
